Removes all cached data from the localintel session cache. Useful when you want to force fresh data fetches from Eurostat, for example after a NUTS classification update.
Removes all cached data from the localintel session cache. Useful when you want to force fresh data fetches from Eurostat, for example after a NUTS classification update.