Count Available Regional Indicators
indicator_count.RdReturns the total number of Eurostat regional indicators in the localintel registry, along with the number of thematic domains.
Value
A named list with indicators (total count),
domains (number of thematic domains), and
by_domain (count per domain)
Examples
n <- indicator_count()
cat(n$indicators, "indicators across", n$domains, "domains\n")
#> 127 indicators across 15 domains